@@ -11,7 +11,7 @@ class saveDialog : public QDialog
 {
     Q_OBJECT
 
-    friend class fourImages;
+    friend class wpNew;
 
 public:
     explicit saveDialog(QWidget *parent = 0);
