@@ -1,14 +1,13 @@
 #ifndef WALLPAEPER_H
 #define WALLPAEPER_H
 
-#include "wpnew.h"
-#include "ui_wpnew.h"
-#include "wpmanager.h"
-#include "ui_wpmanager.h"
-#include "aboutdialog.h"
-#include "ui_aboutdialog.h"
-
 #include <QMainWindow>
+#include <QMenu>
+#include <QMenuBar>
+
+class wpNew;
+class wpManager;
+class aboutDialog;
 
 namespace Ui {
     class wallPaeper;
@@ -26,12 +25,9 @@ private:
     Ui::wallPaeper *ui;
 
     void setupWPMenuBar();
-    // The menu and its actions
-    QMenu* wpMenu;
-    QAction* wpMenuActionAbout;
+    QMenuBar* wpMenuBar;
 
     aboutDialog* abtDialog;
-
     wpNew* newWin;
     wpManager* manWin;
     bool openManWin;
@@ -39,6 +35,7 @@ private:
 
 public slots:
     void createAbtDialog();
+    void createAbtQtDialog();
     void newBtnClicked();
     void manBtnClicked();
     void openWinTrue();
