@@ -1,7 +1,14 @@
 #include "wpnew.h"
 #include "ui_wpnew.h"
-#include "wallpaeper.h"
-#include "ui_wallpaeper.h"
+
+#include "copytodialog.h"
+#include "ui_copytodialog.h"
+
+#include "overwritedialog.h"
+#include "ui_overwritedialog.h"
+
+#include "savedialog.h"
+#include "ui_savedialog.h"
 
 #include <QFileDialog>
 #include <QMaemo5InformationBox>
@@ -28,7 +35,7 @@ wpNew::wpNew(QWidget* parent) :
         imgBtnPrev.append(new QPushButton);
     }
 
-    setupFIMenuBar();
+    setupWPNewMenuBar();
 
     vertLayout[0] = ui->verticalLayout_1;
     vertLayout[1] = ui->verticalLayout_2;
@@ -109,14 +116,10 @@ wpNew::~wpNew() {
 
 
 //********* START wpNew public functions *******************
-void wpNew::setupFIMenuBar() {
-    fiMenuActionReset = new QAction(tr("Reset screen"), this);
-
-    fiMenu = menuBar()->addMenu("");
-    fiMenu->addAction(fiMenuActionReset);
-
-    connect(fiMenuActionReset, SIGNAL(triggered()),
-            this, SLOT(resetScreen()));
+void wpNew::setupWPNewMenuBar() {
+    wpNewMenuBar = new QMenuBar(this);
+    wpNewMenuBar->addMenu("");
+    wpNewMenuBar->addAction(tr("Reset screen"), this, SLOT(resetScreen()));
 }
 
 
