@@ -1,21 +1,18 @@
 #ifndef WPNEW_H
 #define WPNEW_H
 
-#include "copytodialog.h"
-#include "ui_copytodialog.h"
-#include "overwritedialog.h"
-#include "ui_overwritedialog.h"
-#include "savedialog.h"
-#include "ui_savedialog.h"
-
 #include <QMainWindow>
 #include <QLabel>
 #include <QDir>
 #include <QVBoxLayout>
-#include <QMenuBar>
-#include <QMenu>
 #include <QAction>
 #include <QPushButton>
+#include <QMenu>
+#include <QMenuBar>
+
+class copyToDialog;
+class overwriteDialog;
+class saveDialog;
 
 namespace Ui {
     class wpNew;
@@ -46,7 +43,7 @@ protected:
     // Updates imgBtnPrev# according to imgPath(int)
     void updateImgBtnPrev(int);
 
-    void setupFIMenuBar();
+    void setupWPNewMenuBar();
 
     void createOwDialog();
     void checkDesktopFileSaved();
@@ -85,8 +82,7 @@ protected:
     QString* srcPath;
 
     // The menu and its actions
-    QMenu* fiMenu;
-    QAction* fiMenuActionReset;
+    QMenuBar* wpNewMenuBar;
 
     saveDialog* svDialog;
     overwriteDialog* owDialog;
